==> pooltool_billiards-0.4.1.tar.gz: pooltool_billiards-0.4.1/README.md <==
<img src="pooltool/logo/logo.png" width="600" />

[![Project Status: Active – The project has reached a stable, usable state and is being actively developed.](https://www.repostatus.org/badges/latest/active.svg)](https://www.repostatus.org/#active)
[![GitHub license](https://img.shields.io/github/license/ekiefl/pooltool)](https://github.com/ekiefl/pooltool/blob/master/LICENSE.txt)
[![Documentation Status](https://readthedocs.org/projects/pooltool/badge/?version=latest)](https://pooltool.readthedocs.io/en/latest/?badge=latest)
![GitHub Actions Workflow Status](https://img.shields.io/github/actions/workflow/status/ekiefl/pooltool/test.yml)

[![GitHub stars](https://img.shields.io/github/stars/ekiefl/pooltool)](https://github.com/ekiefl/pooltool/stargazers)
[![GitHub forks](https://img.shields.io/github/forks/ekiefl/pooltool)](https://github.com/ekiefl/pooltool/network)
![GitHub commit activity](https://img.shields.io/github/commit-activity/m/ekiefl/pooltool)

![PyPI - Version](https://img.shields.io/pypi/v/pooltool-billiards)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/pooltool-billiards)
[![codecov](https://codecov.io/gh/ekiefl/pooltool/graph/badge.svg)](https://codecov.io/gh/ekiefl/pooltool)

[![Discord](https://img.shields.io/badge/Discord-Join%20Server-7289da?style=for-the-badge&logo=discord&logoColor=white)](https://discord.gg/8Y8qUgzZhz)

# Description

*Pooltool* is a general purpose billiards simulator crafted specifically for science and engineering.

Its core design principles focus on speed, flexibility, and the ease of visualization and analysis. With an interactive 3D interface, a robust API, and extensive documentation, pooltool aims to be a systemic tool in billiards-related research. Continuously evolving through active maintenance and bolstered by a growing community, this vision for pooltool emphasizes not just its current capabilities, but also its potential for growth and adaptation within billiards simulation.

<img src="https://ekiefl.github.io/images/pooltool/pooltool-graphics/gallery_1.png" width="350" /><img src="https://ekiefl.github.io/images/pooltool/pooltool-graphics/gallery_2.png" width="350" /><img src="https://ekiefl.github.io/images/pooltool/pooltool-graphics/gallery_3.png" width="350" /><img src="https://ekiefl.github.io/images/pooltool/pooltool-graphics/gallery_5.png" width="350" /><img src="https://ekiefl.github.io/images/pooltool/pooltool-graphics/gallery_6.png" width="350" /><img src="https://ekiefl.github.io/images/pooltool/pooltool-graphics/gallery_7.png" width="350" />

# Installation

[Installation instructions](https://pooltool.readthedocs.io/en/latest/getting_started/install.html) are hosted on ReadtheDocs.

# Documentation

<a href="https://pooltool.readthedocs.io">
  <img src="https://github.com/ekiefl/pooltool/assets/8688665/744fcd33-2e6a-4b8d-a727-634bb8295124" width="250" alt="rtd">
</a>

All learning resources are found on *Read the Docs*.

Quick links:

1. [Homepage](https://pooltool.readthedocs.io/en/latest/index.html)
1. [Installation](https://pooltool.readthedocs.io/en/latest/getting_started/install.html)
1. [API Reference](https://pooltool.readthedocs.io/en/latest/autoapi/pooltool/index.html)

# Join the community

[![Discord](https://img.shields.io/badge/Discord-Join%20Server-7289da?style=for-the-badge&logo=discord&logoColor=white)](https://discord.gg/8Y8qUgzZhz)

If you want to ask questions, get help, or contribute to the codebase, please join the Discord and introduce yourself.

If the Discord link is expired, please make an issue in this repo.

# Contributing

See [CONTRIBUTING.md](CONTRIBUTING.md).

# Blog

I have blogged about many aspects of this project. Read the detailed account [here](https://ekiefl.github.io/projects/pooltool/).

# Citation

If you use Pooltool in your research/project/product, please cite it.

[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.13119651.svg)](https://doi.org/10.5281/zenodo.13119651)

For your convenience, here are some common citation file formats:

- BibTeX: `wget https://zenodo.org/records/13119651/export/bibtex -O pooltool.bib`
- Citation File Format: `wget https://zenodo.org/records/13119651/export/cff -O pooltool.cff`
- DataCite XML: `wget https://zenodo.org/records/13119651/export/datacite-xml -O pooltool.xml`

==> pooltool_billiards-0.4.2.tar.gz: pooltool_billiards-0.4.2/README.md <==
<img src="https://github.com/ekiefl/pooltool/blob/main/pooltool/logo/logo.png" width="600" />

[![Project Status: Active – The project has reached a stable, usable state and is being actively developed.](https://www.repostatus.org/badges/latest/active.svg)](https://www.repostatus.org/#active)
[![GitHub license](https://img.shields.io/github/license/ekiefl/pooltool)](https://github.com/ekiefl/pooltool/blob/master/LICENSE.txt)
[![Documentation Status](https://readthedocs.org/projects/pooltool/badge/?version=latest)](https://pooltool.readthedocs.io/en/latest/?badge=latest)
![GitHub Actions Workflow Status](https://img.shields.io/github/actions/workflow/status/ekiefl/pooltool/test.yml)

![PyPI - Version](https://img.shields.io/pypi/v/pooltool-billiards)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/pooltool-billiards)
[![codecov](https://codecov.io/gh/ekiefl/pooltool/graph/badge.svg)](https://codecov.io/gh/ekiefl/pooltool)

[![Discord](https://img.shields.io/badge/Discord-Join%20Server-7289da?style=for-the-badge&logo=discord&logoColor=white)](https://discord.gg/8Y8qUgzZhz)

# Description

*Pooltool* is a general purpose billiards simulator crafted specifically for science and engineering.

Its core design principles focus on speed, flexibility, and the ease of visualization and analysis. With an interactive 3D interface, a robust API, and extensive documentation, pooltool aims to be a systemic tool in billiards-related research. Continuously evolving through active maintenance and bolstered by a growing community, this vision for pooltool emphasizes not just its current capabilities, but also its potential for growth and adaptation within billiards simulation.

Pooltool is peer-reviewed and published in the **Journal of Open Source Software** (JOSS) and **pyOpenSci**.

[![DOI](https://joss.theoj.org/papers/10.21105/joss.07301/status.svg)](https://doi.org/10.21105/joss.07301)
[![pyOpenSci Peer-Reviewed](https://pyopensci.org/badges/peer-reviewed.svg)](https://github.com/pyOpenSci/software-review/issues/173)

# Gallery

<img src="https://ekiefl.github.io/images/pooltool/pooltool-graphics/gallery_1.png" width="350" /><img src="https://ekiefl.github.io/images/pooltool/pooltool-graphics/gallery_2.png" width="350" /><img src="https://ekiefl.github.io/images/pooltool/pooltool-graphics/gallery_3.png" width="350" /><img src="https://ekiefl.github.io/images/pooltool/pooltool-graphics/gallery_5.png" width="350" /><img src="https://ekiefl.github.io/images/pooltool/pooltool-graphics/gallery_6.png" width="350" /><img src="https://ekiefl.github.io/images/pooltool/pooltool-graphics/gallery_7.png" width="350" />

# Installation & Documentation

<a href="https://pooltool.readthedocs.io">
  <img src="https://github.com/ekiefl/pooltool/assets/8688665/744fcd33-2e6a-4b8d-a727-634bb8295124" width="200" alt="rtd">
</a>

All resources are hosted at [https://pooltool.readthedocs.io](https://pooltool.readthedocs.io).

Quick links:

1. [🛠️ **Installation**](https://pooltool.readthedocs.io/en/latest/getting_started/install.html)
1. [📚 Examples](https://pooltool.readthedocs.io/en/latest/examples/index.html)
1. [🔌 API Reference](https://pooltool.readthedocs.io/en/latest/autoapi/pooltool/index.html)

# Join the community

[![Discord](https://img.shields.io/badge/Discord-Join%20Server-7289da?style=for-the-badge&logo=discord&logoColor=white)](https://discord.gg/8Y8qUgzZhz)

If you want to ask questions, get help, or contribute to the codebase, please join the Discord and introduce yourself.

If the Discord link is expired, please make an issue in this repo.

# Contributing

See [CONTRIBUTING.md](CONTRIBUTING.md).

# Blog

I have blogged about many aspects of this project. Read the detailed account [here](https://ekiefl.github.io/projects/pooltool/).

# Citation

If you use pooltool in your research/project/product, please cite the JOSS publication:

[![DOI](https://joss.theoj.org/papers/10.21105/joss.07301/status.svg)](https://doi.org/10.21105/joss.07301)

```
@article{Kiefl2024,
    doi = {10.21105/joss.07301},
    url = {https://doi.org/10.21105/joss.07301},
    year = {2024},
    publisher = {The Open Journal},
    volume = {9},
    number = {101},
    pages = {7301},
    author = {Evan Kiefl},
    title = {Pooltool: A Python package for realistic billiards simulation},
    journal = {Journal of Open Source Software}
}
```
